@@ -17,6 +17,7 @@
  *
  * Authors:
  *   James Willcox <jwillcox@cs.indiana.edu>
+ *   Paolo Bacchilega <paobac@cvs.gnome.org>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -192,7 +193,8 @@ egg_recent_view_uimanager_set_list (EggRecentViewUIManager *view, GList *list)
 		action = g_object_new (GTK_TYPE_ACTION,
 				       "name", name,
 				       "label", label,
-				       "stock_id", GTK_STOCK_OPEN,
+				       (view->show_icons)?"stock_id":NULL, 
+				       GTK_STOCK_OPEN,
 				       NULL);
 		if (tooltip != NULL) {
 			g_object_set (action, "tooltip", tooltip, NULL);
